@@ -1,12 +1,11 @@
+import collections.abc
 import decimal
 from abc import ABC
 from datetime import datetime
-import collections.abc
-
 from decimal import Decimal
 
-from quiffen.utils import parse_date, create_categories
 from quiffen.core.categories_classes import Category, Class
+from quiffen.utils import parse_date, create_categories
 
 
 class TransactionList(collections.abc.MutableSequence, ABC):
@@ -448,7 +447,7 @@ class Transaction:
         """
         kwargs = {}
         categories = {}
-        classes = []
+        classes = {}
         splits = TransactionList()
         current_split = None
         split_categories = {}
@@ -514,7 +513,7 @@ class Transaction:
                 # 'L' can store classes, denoted by '/'
                 if '/' in field_info:
                     field_info, class_name = field_info.split('/')[0], field_info.split('/')[1]
-                    classes.append(Class(name=class_name))
+                    classes[class_name] = Class(name=class_name)
 
                 # 'L' can represent both categories and the 'to' transfer account
                 # Transfer accounts are denoted by [ ] so check for those
@@ -541,10 +540,16 @@ class Transaction:
                     else:
                         current_split.category = new_category
             elif line_code == 'N':
-                if not splits:
-                    kwargs['check_number'] = int(field_info)
-                else:
-                    current_split.check_number = int(field_info)
+                try:
+                    if not splits:
+                        kwargs['check_number'] = int(field_info)
+                    else:
+                        current_split.check_number = int(field_info)
+                except ValueError:
+                    # Some financial software stores strings (like
+                    # transaction types) in the check number field,
+                    # ignore anything that is not an integer.
+                    pass
             elif line_code == 'F':
                 if field_info.lower() == 'false':
                     kwargs['reimbursable_expense'] = False
@@ -638,8 +643,9 @@ class Transaction:
                                       if split.percent]) + new_split.percent > 100:
             raise ValueError('Percentage sum of splits cannot add up to more than 100%')
 
-        if new_split.amount and sum([split.amount for split in self._splits if split.amount]) > self._amount:
-            raise ValueError('Splits amounts cannot sum to more than Transaction amount')
+        if new_split.amount and (abs(sum([split.amount for split in self._splits if
+                                          split.amount]) + new_split.amount) > abs(self._amount)):
+            raise ValueError('Splits amounts cannot exceed Transaction amount')
 
         self._splits.append(new_split)
         self.refresh_is_split()
